import React from 'react';
import PropTypes from 'prop-types';
import { Input, Divider, Tree } from 'antd';
import { SearchOutlined } from '@ant-design/icons';
import Empty from '@wisdom-components/Empty';
import styles from './index.less';

const DeviceTree = (props) => {
  const { prefix, placeholder, treeData, onSearch } = props;

  return (
    <div className={styles.DeviceTree}>
      <Input
        prefix={prefix}
        placeholder={placeholder}
        bordered={false}
        onChange={onSearch}
        onPressEnter={onSearch}
      />
      <Divider />
      {!!treeData.length && <Tree {...props} />}
      {!treeData.length && <Empty />}
    </div>
  );
};

DeviceTree.defaultProps = {
  prefix: <SearchOutlined />,
  placeholder: '搜索设备名称',
  treeData: [],
  onSearch: () => {},
};

DeviceTree.propTypes = {
  prefix: PropTypes.node,
  placeholder: PropTypes.string,
  treeData: PropTypes.array,
  onSearch: PropTypes.func,
};

export default DeviceTree;
